@@ -7,7 +7,10 @@ SCRIPTPATH=$(realpath "$(dirname "${BASH_SOURCE[0]}")")
 cd "$SCRIPTPATH/.."
 
 if [[ ! -d r2dec-js ]]; then
-	git clone --depth 1 https://github.com/wargio/r2dec-js.git
+	git clone https://github.com/wargio/r2dec-js.git
+	cd r2dec-js
+	git checkout b5a0d15c7bcc488f268ffb0931b7ced2919f6c9d
+	cd ..
 fi
 
 cd r2dec-js
