@@ -1,11 +1,16 @@
 #!/bin/bash
 
+set -e
+
 SCRIPTPATH=$(realpath "$(dirname "${BASH_SOURCE[0]}")")
 
 cd "$SCRIPTPATH/.."
 
 if [[ ! -d r2ghidra-dec ]]; then
-    git clone --depth 1 --recurse-submodules https://github.com/radareorg/r2ghidra-dec.git || exit 1
+    git clone --recurse-submodules https://github.com/radareorg/r2ghidra-dec.git || exit 1
+    pushd r2ghidra-dec
+    git checkout  --recurse-submodules 8e576eeadc211de4ac8d8c759cc368fa48cdfa99
+    popd
 fi
 cd r2ghidra-dec || exit 1
 
