@@ -14,6 +14,7 @@
 #include <QJsonDocument>
 #include <QErrorMessage>
 #include <QMutex>
+#include <QDir>
 
 class AsyncTaskManager;
 class BasicInstructionHighlighter;
@@ -22,16 +23,16 @@ class Decompiler;
 class R2Task;
 class R2TaskDialog;
 
-#include "plugins/CutterPlugin.h"
 #include "common/BasicBlockHighlighter.h"
 #include "common/R2Task.h"
+#include "common/Helpers.h"
 #include "dialogs/R2TaskDialog.h"
 
 #define Core() (CutterCore::instance())
 
 class RCoreLocked;
 
-class CutterCore: public QObject
+class CUTTER_EXPORT CutterCore: public QObject
 {
     Q_OBJECT
 
@@ -43,9 +44,11 @@ public:
     ~CutterCore();
     static CutterCore *instance();
 
-    void initialize();
+    void initialize(bool loadPlugins = true);
     void loadCutterRC();
-
+    void loadDefaultCutterRC();
+    QDir getCutterRCDefaultDirectory() const;
+    
     AsyncTaskManager *getAsyncTaskManager() { return asyncTaskManager; }
 
     RVA getOffset() const                   { return core_->offset; }
@@ -72,10 +75,41 @@ public:
      */
     bool asyncCmd(const char *str, QSharedPointer<R2Task> &task);
     bool asyncCmd(const QString &str, QSharedPointer<R2Task> &task) { return asyncCmd(str.toUtf8().constData(), task); }
-    QString cmdRaw(const QString &str);
+
+    /**
+     * @brief Execute a radare2 command \a cmd.  By nature, the API
+     * is executing raw commands, and thus ignores multiple commands and overcome command injections.
+     * @param cmd - a raw command to execute. Passing multiple commands (e.g "px 5; pd 7 && pdf") will result in them treated as arguments to first command.
+     * @return the output of the command
+     */
+    QString cmdRaw(const char *cmd);
+
+    /**
+     * @brief a wrapper around cmdRaw(const char *cmd,).
+     */
+    QString cmdRaw(const QString &cmd) { return cmdRaw(cmd.toUtf8().constData()); };
+
+    /**
+     * @brief Execute a radare2 command \a cmd at \a address. The function will preform a silent seek to the address
+     * without triggering the seekChanged event nor adding new entries to the seek history. By nature, the
+     * API is executing a single command without going through radare2 shell, and thus ignores multiple commands 
+     * and tries to overcome command injections.
+     * @param cmd - a raw command to execute. If multiple commands will be passed (e.g "px 5; pd 7 && pdf") then
+     * only the first command will be executed.
+     * @param address - an address to which Cutter will temporarily seek.
+     * @return the output of the command
+     */
+    QString cmdRawAt(const char *cmd, RVA address);
+    
+    /**
+     * @brief a wrapper around cmdRawAt(const char *cmd, RVA address).
+     */
+    QString cmdRawAt(const QString &str, RVA address) { return cmdRawAt(str.toUtf8().constData(), address); }
+    
     QJsonDocument cmdj(const char *str);
     QJsonDocument cmdj(const QString &str) { return cmdj(str.toUtf8().constData()); }
-    QStringList cmdList(const char *str) { return cmd(str).split(QLatin1Char('\n'), QString::SkipEmptyParts); }
+    QJsonDocument cmdjAt(const char *str, RVA address);
+    QStringList cmdList(const char *str) { return cmd(str).split(QLatin1Char('\n'), CUTTER_QT_SKIP_EMPTY_PARTS); }
     QStringList cmdList(const QString &str) { return cmdList(str.toUtf8().constData()); }
     QString cmdTask(const QString &str);
     QJsonDocument cmdjTask(const QString &str);
@@ -109,9 +143,18 @@ public:
     QStringList autocomplete(const QString &cmd, RLinePromptType promptType, size_t limit = 4096);
 
     /* Functions methods */
-    void renameFunction(const QString &oldName, const QString &newName);
+    void renameFunction(const RVA offset, const QString &newName);
     void delFunction(RVA addr);
     void renameFlag(QString old_name, QString new_name);
+    /**
+     * @brief Renames the specified local variable in the function specified by the
+     * address given.
+     * @param newName Specifies the name to which the current name of the variable
+     * should be renamed.
+     * @param oldName Specifies the current name of the function variable.
+     * @param functionAddress Specifies the exact address of the function.
+     */
+    void renameFunctionVariable(QString newName, QString oldName, RVA functionAddress);
 
     /**
      * @param addr
@@ -138,6 +181,7 @@ public:
     void delFlag(RVA addr);
     void delFlag(const QString &name);
     void addFlag(RVA offset, QString name, RVA size);
+    QString listFlagsAsStringAt(RVA addr);
     /**
      * @brief Get nearest flag at or before offset.
      * @param offset search position
@@ -186,6 +230,7 @@ public:
     /* Comments */
     void setComment(RVA addr, const QString &cmt);
     void delComment(RVA addr);
+    QString getCommentAt(RVA addr);
     void setImmediateBase(const QString &r2BaseName, RVA offset = RVA_INVALID);
     void setCurrentBits(int bits, RVA offset = RVA_INVALID);
 
@@ -214,13 +259,15 @@ public:
     bool loadFile(QString path, ut64 baddr = 0LL, ut64 mapaddr = 0LL, int perms = R_PERM_R,
                   int va = 0, bool loadbin = false, const QString &forceBinPlugin = QString());
     bool tryFile(QString path, bool rw);
-    bool openFile(QString path, RVA mapaddr);
+    bool mapFile(QString path, RVA mapaddr);
     void loadScript(const QString &scriptname);
     QJsonArray getOpenedFiles();
 
     /* Seek functions */
     void seek(QString thing);
     void seek(ut64 offset);
+    void seekSilent(ut64 offset);
+    void seekSilent(QString thing) { seekSilent(math(thing)); }
     void seekPrev();
     void seekNext();
     void updateSeek();
@@ -249,6 +296,8 @@ public:
     QString itoa(ut64 num, int rdx = 16);
 
     /* Config functions */
+    void setConfig(const char *k, const char *v);
+    void setConfig(const QString &k, const char *v);
     void setConfig(const char *k, const QString &v);
     void setConfig(const QString &k, const QString &v) { setConfig(k.toUtf8().constData(), v); }
     void setConfig(const char *k, int v);
@@ -351,11 +400,9 @@ public:
     void stepOverDebug();
     void stepOutDebug();
 
-    void addBreakpoint(QString addr);
     void addBreakpoint(const BreakpointDescription &config);
     void updateBreakpoint(int index, const BreakpointDescription &config);
     void toggleBreakpoint(RVA addr);
-    void toggleBreakpoint(QString addr);
     void delBreakpoint(RVA addr);
     void delAllBreakpoints();
     void enableBreakpoint(RVA addr);
@@ -525,9 +572,19 @@ public:
      * @param depth telescoping depth
      */
     QList<QJsonObject> getRegisterRefs(int depth = 6);
-    QJsonObject getRegisterJson();
+    QVector<RegisterRefValueDescription> getRegisterRefValues();
     QList<VariableDescription> getVariables(RVA at);
-
+    /**
+     * @brief Fetches all the writes or reads to the specified local variable 'variableName'
+     * in the function in which the specified offset is a part of.
+     * @param variableName Name of the local variable.
+     * @param findWrites If this is true, then locations at which modification happen to the specified
+     * local variable is fetched. Else, the locations at which the local is variable is read is fetched.
+     * @param offset An offset in the function in which the specified local variable exist.
+     * @return A list of XrefDescriptions that contains details of all the writes or reads that happen to the
+     * variable 'variableName'.
+     */
+    QList<XrefDescription> getXRefsForVariable(QString variableName, bool findWrites, RVA offset);
     QList<XrefDescription> getXRefs(RVA addr, bool to, bool whole_function,
                                     const QString &filterType = QString());
 
@@ -537,7 +594,7 @@ public:
 
     /* Signals related */
     void triggerVarsChanged();
-    void triggerFunctionRenamed(const QString &prevName, const QString &newName);
+    void triggerFunctionRenamed(const RVA offset, const QString &newName);
     void triggerRefreshAll();
     void triggerAsmOptionsChanged();
     void triggerGraphOptionsChanged();
@@ -552,17 +609,48 @@ public:
     BasicBlockHighlighter *getBBHighlighter();
     BasicInstructionHighlighter *getBIHighlighter();
 
+    /**
+     * @brief Enable or dsiable Cache mode. Cache mode is used to imagine writing to the opened file
+     * without committing the changes to the disk.
+     * @param enabled
+     */
+    void setIOCache(bool enabled);
+
+    /**
+     * @brief Check if Cache mode is enabled.
+     * @return true if Cache is enabled, otherwise return false.
+     */
+    bool isIOCacheEnabled() const;
+
+    /**
+     * @brief Commit write cache to the file on disk.
+     */
+    void commitWriteCache();
+
+    /**
+     * @brief Enable or disable Write mode. When the file is opened in write mode, any changes to it will be immediately
+     * committed to the file on disk, thus modify the file. This function wrap radare2 function which re-open the file with
+     * the desired permissions.
+     * @param enabled
+     */
+    void setWriteMode(bool enabled);
+    /**
+     * @brief Check if the file is opened in write mode.
+     * @return true if write mode is enabled, otherwise return false.
+     */
+    bool isWriteModeEnabled();
+
 signals:
     void refreshAll();
 
-    void functionRenamed(const QString &prev_name, const QString &new_name);
+    void functionRenamed(const RVA offset, const QString &new_name);
     void varsChanged();
     void functionsChanged();
     void flagsChanged();
-    void commentsChanged();
+    void commentsChanged(RVA addr);
     void registersChanged();
     void instructionChanged(RVA offset);
-    void breakpointsChanged();
+    void breakpointsChanged(RVA offset);
     void refreshCodeViews();
     void stackChanged();
     /**
@@ -587,6 +675,10 @@ signals:
 
     void projectSaved(bool successfully, const QString &name);
 
+    void ioCacheChanged(bool newval);
+    void writeModeChanged(bool newval);
+    void ioModeChanged();
+
     /**
      * emitted when debugTask started or finished running
      */
@@ -635,13 +727,16 @@ private:
 
     bool emptyGraph = false;
     BasicBlockHighlighter *bbHighlighter;
+    bool iocache = false;
     BasicInstructionHighlighter biHighlighter;
 
     QSharedPointer<R2Task> debugTask;
     R2TaskDialog *debugTaskDialog;
+    
+    QVector<QString> getCutterRCFilePaths() const;
 };
 
-class RCoreLocked
+class CUTTER_EXPORT RCoreLocked
 {
     CutterCore * const core;
 
