@@ -9,14 +9,17 @@
 
 EditVariablesDialog::EditVariablesDialog(RVA offset, QString initialVar, QWidget *parent) :
     QDialog(parent),
-    ui(new Ui::EditVariablesDialog)
+    ui(new Ui::EditVariablesDialog),
+    functionAddress(RVA_INVALID)
 {
     ui->setupUi(this);
-    connect(ui->buttonBox, SIGNAL(accepted()), this, SLOT(applyFields()));
-    connect(ui->dropdownLocalVars, SIGNAL(currentIndexChanged(int)), SLOT(updateFields()));
+    connect(ui->buttonBox, &QDialogButtonBox::accepted, this, &EditVariablesDialog::applyFields);
+    connect<void(QComboBox::*)(int)>(ui->dropdownLocalVars, &QComboBox::currentIndexChanged,
+                                     this, &EditVariablesDialog::updateFields);
 
-    QString fcnName = Core()->cmd(QString("afn @ %1").arg(offset)).trimmed();
-    setWindowTitle(tr("Set Variable Types for Function: %1").arg(fcnName));
+    QString fcnName = Core()->cmdRawAt("afn.", offset).trimmed();
+    functionAddress = offset;
+    setWindowTitle(tr("Edit Variables in Function: %1").arg(fcnName));
 
     variables = Core()->getVariables(offset);
     int currentItemIndex = -1;
@@ -62,7 +65,7 @@ void EditVariablesDialog::applyFields()
             .replace(QLatin1Char('\\'), QLatin1Char('_'))
             .replace(QLatin1Char('/'), QLatin1Char('_'));
     if (newName != desc.name) {
-        Core()->cmdRaw(QString("afvn %1 %2").arg(newName).arg(desc.name));
+        Core()->renameFunctionVariable(newName, desc.name, functionAddress);
     }
 
     // Refresh the views to reflect the changes to vars
