@@ -27,13 +27,15 @@ AsmOptionsWidget::AsmOptionsWidget(PreferencesDialog *dialog)
         { ui->xrefCheckBox,         "asm.xrefs" },
         { ui->bblineCheckBox,       "asm.bb.line" },
         { ui->varsubCheckBox,       "asm.var.sub" },
-        { ui->varsubOnlyCheckBox,   "asm.var.subonly" },
+        { ui->varsubOnlyCheckBox,   "asm.sub.varonly" },
         { ui->lbytesCheckBox,       "asm.lbytes" },
-        { ui->bytespaceCheckBox,    "asm.bytespace" },
+        { ui->bytespaceCheckBox,    "asm.bytes.space" },
         { ui->bytesCheckBox,        "asm.bytes" },
         { ui->xrefCheckBox,         "asm.xrefs" },
         { ui->indentCheckBox,       "asm.indent" },
         { ui->offsetCheckBox,       "asm.offset" },
+        { ui->relOffsetCheckBox,    "asm.reloff" },
+        { ui->relOffFlagsCheckBox,  "asm.reloff.flags" },
         { ui->slowCheckBox,         "asm.slow" },
         { ui->linesCheckBox,        "asm.lines" },
         { ui->fcnlinesCheckBox,     "asm.lines.fcn" },
@@ -60,7 +62,9 @@ AsmOptionsWidget::AsmOptionsWidget(PreferencesDialog *dialog)
                 &AsmOptionsWidget::commentsComboBoxChanged);
     connect(ui->asmComboBox, static_cast<indexSignalType>(&QComboBox::currentIndexChanged), this,
                 &AsmOptionsWidget::asmComboBoxChanged);
-    connect(Core(), SIGNAL(asmOptionsChanged()), this, SLOT(updateAsmOptionsFromVars()));
+    connect(ui->offsetCheckBox, &QCheckBox::toggled, this, &AsmOptionsWidget::offsetCheckBoxToggled);
+    connect(ui->relOffsetCheckBox, &QCheckBox::toggled, this, &AsmOptionsWidget::relOffCheckBoxToggled);
+    connect(Core(), &CutterCore::asmOptionsChanged, this, &AsmOptionsWidget::updateAsmOptionsFromVars);
     updateAsmOptionsFromVars();
 }
 
@@ -75,6 +79,11 @@ void AsmOptionsWidget::updateAsmOptionsFromVars()
     ui->cmtcolSpinBox->blockSignals(false);
     ui->cmtcolSpinBox->setEnabled(cmtRightEnabled);
 
+    bool offsetsEnabled = Config()->getConfigBool("asm.offset") || Config()->getConfigBool("graph.offset");
+    ui->relOffsetLabel->setEnabled(offsetsEnabled);
+    ui->relOffsetCheckBox->setEnabled(offsetsEnabled);
+    ui->relOffFlagsCheckBox->setEnabled(Config()->getConfigBool("asm.offset") && Config()->getConfigBool("asm.reloff"));
+
     bool bytesEnabled = Config()->getConfigBool("asm.bytes");
     ui->bytespaceCheckBox->setEnabled(bytesEnabled);
     ui->lbytesCheckBox->setEnabled(bytesEnabled);
@@ -133,9 +142,9 @@ void AsmOptionsWidget::resetToDefault()
 
 void AsmOptionsWidget::triggerAsmOptionsChanged()
 {
-    disconnect(Core(), SIGNAL(asmOptionsChanged()), this, SLOT(updateAsmOptionsFromVars()));
+    disconnect(Core(), &CutterCore::asmOptionsChanged, this, &AsmOptionsWidget::updateAsmOptionsFromVars);
     Core()->triggerAsmOptionsChanged();
-    connect(Core(), SIGNAL(asmOptionsChanged()), this, SLOT(updateAsmOptionsFromVars()));
+    connect(Core(), &CutterCore::asmOptionsChanged, this, &AsmOptionsWidget::updateAsmOptionsFromVars);
 }
 
 void AsmOptionsWidget::on_cmtcolSpinBox_valueChanged(int value)
@@ -144,7 +153,6 @@ void AsmOptionsWidget::on_cmtcolSpinBox_valueChanged(int value)
     triggerAsmOptionsChanged();
 }
 
-
 void AsmOptionsWidget::on_bytesCheckBox_toggled(bool checked)
 {
     Config()->setConfig("asm.bytes", checked);
@@ -257,6 +265,18 @@ void AsmOptionsWidget::asmComboBoxChanged(int index)
     triggerAsmOptionsChanged();
 }
 
+void AsmOptionsWidget::offsetCheckBoxToggled(bool checked)
+{
+    ui->relOffsetLabel->setEnabled(checked || Config()->getConfigBool("graph.offset"));
+    ui->relOffsetCheckBox->setEnabled(checked || Config()->getConfigBool("graph.offset"));
+    ui->relOffFlagsCheckBox->setEnabled(checked && Config()->getConfigBool("asm.reloff"));
+}
+
+void AsmOptionsWidget::relOffCheckBoxToggled(bool checked)
+{
+    ui->relOffFlagsCheckBox->setEnabled(checked && Config()->getConfigBool("asm.offset"));
+}
+
 /**
  * @brief A generic signal to handle the simple cases where a checkbox is toggled
  * while it only responsible for a single independent boolean configuration eval.
