@@ -3,7 +3,6 @@
 #include "dialogs/EditInstructionDialog.h"
 #include "dialogs/CommentsDialog.h"
 #include "dialogs/FlagDialog.h"
-#include "dialogs/RenameDialog.h"
 #include "dialogs/XrefsDialog.h"
 #include "dialogs/EditVariablesDialog.h"
 #include "dialogs/SetToDataDialog.h"
@@ -19,6 +18,7 @@
 #include <QClipboard>
 #include <QApplication>
 #include <QPushButton>
+#include <QInputDialog>
 
 DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *mainWindow)
     :   QMenu(parent),
@@ -39,6 +39,7 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
         actionRenameUsedHere(this),
         actionSetFunctionVarTypes(this),
         actionXRefs(this),
+        actionXRefsForVariables(this),
         actionDisplayOptions(this),
         actionDeleteComment(this),
         actionDeleteFlag(this),
@@ -56,9 +57,9 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
         actionSetBits32(this),
         actionSetBits64(this),
         actionContinueUntil(this),
+        actionSetPC(this),
         actionAddBreakpoint(this),
         actionAdvancedBreakpoint(this),
-        actionSetPC(this),
         actionSetToCode(this),
         actionSetAsStringAuto(this),
         actionSetAsStringRemove(this),
@@ -102,7 +103,7 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
                SLOT(on_actionRenameUsedHere_triggered()), getRenameUsedHereSequence());
     addAction(&actionRenameUsedHere);
 
-    initAction(&actionSetFunctionVarTypes, tr("Re-type function local vars"),
+    initAction(&actionSetFunctionVarTypes, tr("Re-type Local Variables"),
                SLOT(on_actionSetFunctionVarTypes_triggered()), getRetypeSequence());
     addAction(&actionSetFunctionVarTypes);
 
@@ -127,8 +128,8 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
     addSetBitsMenu();
 
     structureOffsetMenu = addMenu(tr("Structure offset"));
-    connect(structureOffsetMenu, SIGNAL(triggered(QAction*)),
-            this, SLOT(on_actionStructureOffsetMenu_triggered(QAction*)));
+    connect(structureOffsetMenu, &QMenu::triggered,
+            this, &DisassemblyContextMenu::on_actionStructureOffsetMenu_triggered);
 
     initAction(&actionLinkType, tr("Link Type to Address"),
                SLOT(on_actionLinkType_triggered()), getLinkTypeSequence());
@@ -142,6 +143,10 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
                SLOT(on_actionXRefs_triggered()), getXRefSequence());
     addAction(&actionXRefs);
 
+    initAction(&actionXRefsForVariables, tr("X-Refs for local variables"),
+                SLOT(on_actionXRefsForVariables_triggered()), QKeySequence({Qt::SHIFT + Qt::Key_X}));
+    addAction(&actionXRefsForVariables);
+
     initAction(&actionDisplayOptions, tr("Show Options"),
                SLOT(on_actionDisplayOptions_triggered()), getDisplayOptionsSequence());
 
@@ -165,6 +170,8 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
 
     connect(this, &DisassemblyContextMenu::aboutToShow,
             this, &DisassemblyContextMenu::aboutToShowSlot);
+    connect(this, &DisassemblyContextMenu::aboutToHide,
+            this, &DisassemblyContextMenu::aboutToHideSlot);
 }
 
 DisassemblyContextMenu::~DisassemblyContextMenu()
@@ -241,7 +248,7 @@ void DisassemblyContextMenu::addSetAsMenu()
     initAction(&actionSetAsStringRemove, tr("Remove"),
                SLOT(on_actionSetAsStringRemove_triggered()));
     initAction(&actionSetAsStringAdvanced, tr("Advanced"),
-               SLOT(on_actionSetAsStringAdvanced_triggered()));
+               SLOT(on_actionSetAsStringAdvanced_triggered()), getSetAsStringAdvanced());
 
 
     setAsString->addAction(&actionSetAsStringAuto);
@@ -459,7 +466,12 @@ void DisassemblyContextMenu::aboutToShowSlot()
 
     actionAnalyzeFunction.setVisible(true);
 
-    QString comment = Core()->cmd("CC." + RAddressString(offset));
+    // Show the option to remove a defined string only if a string is defined in this address
+    QString stringDefinition = Core()->cmdRawAt("Cs.", offset);
+    actionSetAsStringRemove.setVisible(!stringDefinition.isEmpty());
+
+    QString comment = Core()->cmdRawAt("CC.", offset);
+
     if (comment.isNull() || comment.isEmpty()) {
         actionDeleteComment.setVisible(false);
         actionAddComment.setText(tr("Add Comment"));
@@ -554,6 +566,17 @@ void DisassemblyContextMenu::aboutToShowSlot()
             pluginAction->setData(QVariant::fromValue(offset));
         }
     }
+
+    bool isLocalVar = isHighlightedWordLocalVar();
+    actionXRefsForVariables.setVisible(isLocalVar);
+    if (isLocalVar) {
+        actionXRefsForVariables.setText(tr("X-Refs for %1").arg(curHighlightedWord));
+    }
+}
+
+void DisassemblyContextMenu::aboutToHideSlot()
+{
+    actionXRefsForVariables.setVisible(true);
 }
 
 QKeySequence DisassemblyContextMenu::getCopySequence() const
@@ -581,6 +604,10 @@ QKeySequence DisassemblyContextMenu::getSetAsStringSequence() const
     return {Qt::Key_A};
 }
 
+QKeySequence DisassemblyContextMenu::getSetAsStringAdvanced() const
+{
+	return {Qt::SHIFT + Qt::Key_A};
+}
 
 QKeySequence DisassemblyContextMenu::getSetToDataSequence() const
 {
@@ -650,6 +677,9 @@ QKeySequence DisassemblyContextMenu::getUndefineFunctionSequence() const
 
 void DisassemblyContextMenu::on_actionEditInstruction_triggered()
 {
+    if (!ioModesController.prepareForWriting()) {
+        return;
+    }
     EditInstructionDialog e(EDIT_TEXT, this);
     e.setWindowTitle(tr("Edit Instruction at %1").arg(RAddressString(offset)));
 
@@ -662,30 +692,16 @@ void DisassemblyContextMenu::on_actionEditInstruction_triggered()
         QString userInstructionOpcode = e.getInstruction();
         if (userInstructionOpcode != oldInstructionOpcode) {
             Core()->editInstruction(offset, userInstructionOpcode);
-
-            // Check if the write failed
-            auto newInstructionBytes = Core()->getInstructionBytes(offset);
-            if (newInstructionBytes == oldInstructionBytes) {
-                if (!writeFailed()) {
-                    Core()->editInstruction(offset, userInstructionOpcode);
-                }
-            }
         }
     }
 }
 
 void DisassemblyContextMenu::on_actionNopInstruction_triggered()
 {
-    QString oldBytes = Core()->getInstructionBytes(offset);
-
-    Core()->nopInstruction(offset);
-
-    QString newBytes = Core()->getInstructionBytes(offset);
-    if (oldBytes == newBytes) {
-        if (!writeFailed()) {
-            Core()->nopInstruction(offset);
-        }
+    if (!ioModesController.prepareForWriting()) {
+        return;
     }
+    Core()->nopInstruction(offset);
 }
 
 void DisassemblyContextMenu::showReverseJmpQuery()
@@ -707,20 +723,17 @@ void DisassemblyContextMenu::showReverseJmpQuery()
 
 void DisassemblyContextMenu::on_actionJmpReverse_triggered()
 {
-    QString oldBytes = Core()->getInstructionBytes(offset);
-
-    Core()->jmpReverse(offset);
-
-    QString newBytes = Core()->getInstructionBytes(offset);
-    if (oldBytes == newBytes) {
-        if (!writeFailed()) {
-            Core()->jmpReverse(offset);
-        }
+    if (!ioModesController.prepareForWriting()) {
+        return;
     }
+    Core()->jmpReverse(offset);
 }
 
 void DisassemblyContextMenu::on_actionEditBytes_triggered()
 {
+    if (!ioModesController.prepareForWriting()) {
+        return;
+    }
     EditInstructionDialog e(EDIT_BYTES, this);
     e.setWindowTitle(tr("Edit Bytes at %1").arg(RAddressString(offset)));
 
@@ -731,38 +744,10 @@ void DisassemblyContextMenu::on_actionEditBytes_triggered()
         QString bytes = e.getInstruction();
         if (bytes != oldBytes) {
             Core()->editBytes(offset, bytes);
-
-            QString newBytes = Core()->getInstructionBytes(offset);
-            if (oldBytes == newBytes) {
-                if (!writeFailed()) {
-                    Core()->editBytes(offset, bytes);
-                }
-            }
         }
     }
 }
 
-bool DisassemblyContextMenu::writeFailed()
-{
-    QMessageBox msgBox;
-    msgBox.setIcon(QMessageBox::Icon::Critical);
-    msgBox.setWindowTitle(tr("Write error"));
-    msgBox.setText(
-        tr("Unable to complete write operation. Consider opening in write mode. \n\nWARNING: In write mode any changes will be committed to disk"));
-    msgBox.addButton(tr("OK"), QMessageBox::NoRole);
-    QAbstractButton *reopenButton = msgBox.addButton(tr("Reopen in write mode and try again"),
-                                                     QMessageBox::YesRole);
-
-    msgBox.exec();
-
-    if (msgBox.clickedButton() == reopenButton) {
-        Core()->cmd("oo+");
-        return false;
-    }
-
-    return true;
-}
-
 void DisassemblyContextMenu::on_actionCopy_triggered()
 {
     emit copy();
@@ -807,12 +792,14 @@ void DisassemblyContextMenu::on_actionAddComment_triggered()
 
 void DisassemblyContextMenu::on_actionAnalyzeFunction_triggered()
 {
-    RenameDialog dialog(mainWindow);
-    dialog.setWindowTitle(tr("Analyze function at %1").arg(RAddressString(offset)));
-    dialog.setPlaceholderText(tr("Function name"));
-    if (dialog.exec()) {
-        QString function_name = dialog.getName();
-        Core()->createFunctionAt(offset, function_name);
+    bool ok;
+    // Create dialog
+    QString functionName = QInputDialog::getText(this, tr("New function %1").arg(RAddressString(offset)),
+                            tr("Function name:"), QLineEdit::Normal, QString(), &ok);
+
+    // If user accepted
+    if (ok && !functionName.isEmpty()) {
+        Core()->createFunctionAt(offset, functionName);
     }
 }
 
@@ -825,69 +812,67 @@ void DisassemblyContextMenu::on_actionAddFlag_triggered()
 void DisassemblyContextMenu::on_actionRename_triggered()
 {
     RCore *core = Core()->core();
+    bool ok;
+    
+    RAnalFunction *fcn = Core()->functionIn(offset);
+    RFlagItem *f = r_flag_get_i(core->flags, offset);
 
-    RenameDialog dialog(mainWindow);
-
-    RAnalFunction *fcn = Core()->functionIn (offset);
-    RFlagItem *f = r_flag_get_i (core->flags, offset);
     if (fcn) {
-        /* Rename function */
-        dialog.setWindowTitle(tr("Rename function %1").arg(fcn->name));
-        dialog.setName(fcn->name);
-        if (dialog.exec()) {
-            QString new_name = dialog.getName();
-            Core()->renameFunction(fcn->name, new_name);
+        // Renaming a function
+        QString newName = QInputDialog::getText(this->mainWindow, tr("Rename function %2").arg(fcn->name),
+                                            tr("Function name:"), QLineEdit::Normal, fcn->name, &ok);
+        if (ok && !newName.isEmpty()) {
+            Core()->renameFunction(fcn->addr, newName);
         }
     } else if (f) {
-        /* Rename current flag */
-        dialog.setWindowTitle(tr("Rename flag %1").arg(f->name));
-        dialog.setName(f->name);
-        if (dialog.exec()) {
-            QString new_name = dialog.getName();
-            Core()->renameFlag(f->name, new_name);
+        // Renaming flag
+        QString newName = QInputDialog::getText(this, tr("Rename flag %2").arg(f->name),
+                                            tr("Flag name:"), QLineEdit::Normal, f->name, &ok);
+        if (ok && !newName.isEmpty()) {
+            Core()->renameFlag(f->name, newName);
         }
-    } else {
-        return;
     }
 }
 
 void DisassemblyContextMenu::on_actionRenameUsedHere_triggered()
 {
+
+    QString title;
+    QString inputValue;
+    QString oldName;
+
     auto array = getThingUsedHere(offset);
     if (array.isEmpty()) {
         return;
     }
 
     auto thingUsedHere = array.first();
-
-    RenameDialog dialog(mainWindow);
-
-    QString oldName;
     auto type = thingUsedHere.type;
 
     if (type == ThingUsedHere::Type::Address) {
         RVA offset = thingUsedHere.offset;
-        dialog.setWindowTitle(tr("Add flag at %1").arg(RAddressString(offset)));
-        dialog.setName("label." + QString::number(offset, 16));
+        title = tr("Add flag at %1").arg(RAddressString(offset));
+        inputValue = "label." + QString::number(offset, 16);
     } else {
         oldName = thingUsedHere.name;
-        dialog.setWindowTitle(tr("Rename %1").arg(oldName));
-        dialog.setName(oldName);
+        title = tr("Rename %1").arg(oldName);
+        inputValue = oldName;
     }
 
+    bool ok;
+    // Create dialog
+    QString newName = QInputDialog::getText(this, title,
+                            tr("Name:"), QLineEdit::Normal, inputValue, &ok);
 
-    if (dialog.exec()) {
-        QString newName = dialog.getName().trimmed();
-        if (!newName.isEmpty()) {
-            Core()->cmd("an " + newName + " @ " + QString::number(offset));
-
-            if (type == ThingUsedHere::Type::Address || type == ThingUsedHere::Type::Flag) {
-                Core()->triggerFlagsChanged();
-            } else if (type == ThingUsedHere::Type::Var) {
-                Core()->triggerVarsChanged();
-            } else if (type == ThingUsedHere::Type::Function) {
-                Core()->triggerFunctionRenamed(oldName, newName);
-            }
+    // If user accepted
+    if (ok && !newName.isEmpty()) {
+        Core()->cmdRawAt(QString("an %1").arg(newName), offset);
+        if (type == ThingUsedHere::Type::Address || type == ThingUsedHere::Type::Flag) {
+            Core()->triggerFlagsChanged();
+        } else if (type == ThingUsedHere::Type::Var) {
+            Core()->triggerVarsChanged();
+        } else if (type == ThingUsedHere::Type::Function) {
+            Core()->triggerFunctionRenamed(thingUsedHere.offset, newName);
         }
     }
 }
@@ -897,12 +882,12 @@ void DisassemblyContextMenu::on_actionSetFunctionVarTypes_triggered()
     RAnalFunction *fcn = Core()->functionIn(offset);
 
     if (!fcn) {
-        QMessageBox::critical(this, tr("Re-type function local vars"),
+        QMessageBox::critical(this, tr("Re-type Local Variables"),
                               tr("You must be in a function to define variable types."));
         return;
     }
 
-    EditVariablesDialog dialog(Core()->getOffset(), curHighlightedWord, this);
+    EditVariablesDialog dialog(fcn->addr, curHighlightedWord, this);
     if (dialog.empty()) { // don't show the dialog if there are no variables
         return;
     }
@@ -916,6 +901,15 @@ void DisassemblyContextMenu::on_actionXRefs_triggered()
     dialog.exec();
 }
 
+void DisassemblyContextMenu::on_actionXRefsForVariables_triggered()
+{
+    if (isHighlightedWordLocalVar()) {
+        XrefsDialog dialog(mainWindow, nullptr);
+        dialog.fillRefsForVariable(curHighlightedWord, offset);
+        dialog.exec();
+    }
+}
+
 void DisassemblyContextMenu::on_actionDisplayOptions_triggered()
 {
     PreferencesDialog dialog(this->window());
@@ -1040,11 +1034,9 @@ void DisassemblyContextMenu::on_actionEditFunction_triggered()
         QString startAddrText = "0x" + QString::number(fcn->addr, 16);
         dialog.setStartAddrText(startAddrText);
 
-        QString stackSizeText;
-        stackSizeText.sprintf("%d", fcn->stack);
-        dialog.setStackSizeText(stackSizeText);
+        dialog.setStackSizeText(QString::number(fcn->stack));
 
-        QStringList callConList = Core()->cmd("afcl").split("\n");
+        QStringList callConList = Core()->cmdRaw("afcl").split("\n");
         callConList.removeLast();
         dialog.setCallConList(callConList);
         dialog.setCallConSelected(fcn->cc);
@@ -1052,12 +1044,12 @@ void DisassemblyContextMenu::on_actionEditFunction_triggered()
 
         if (dialog.exec()) {
             QString new_name = dialog.getNameText();
-            Core()->renameFunction(fcn->name, new_name);
+            Core()->renameFunction(fcn->addr, new_name);
             QString new_start_addr = dialog.getStartAddrText();
             fcn->addr = Core()->math(new_start_addr);
             QString new_stack_size = dialog.getStackSizeText();
             fcn->stack = int(Core()->math(new_stack_size));
-            Core()->cmd("afc " + dialog.getCallConSelected());
+            Core()->cmdRaw("afc " + dialog.getCallConSelected());
             emit Core()->functionsChanged();
         }
     }
@@ -1119,3 +1111,14 @@ void DisassemblyContextMenu::initAction(QAction *action, QString name,
     action->setShortcuts(keySequenceList);
     action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 }
+
+bool DisassemblyContextMenu::isHighlightedWordLocalVar()
+{
+    QList<VariableDescription> variables = Core()->getVariables(offset);
+    for (const VariableDescription &var : variables) {
+        if (var.name == curHighlightedWord) {
+            return true;
+        }
+    }
+    return false;
+}
