@@ -4,11 +4,11 @@
 #include "common/Helpers.h"
 #include "common/SvgIconEngine.h"
 #include "dialogs/EditMethodDialog.h"
-#include "dialogs/RenameDialog.h"
 
 #include <QList>
 #include <QMenu>
 #include <QMouseEvent>
+#include <QInputDialog>
 
 QVariant ClassesModel::headerData(int section, Qt::Orientation, int role) const
 {
@@ -575,8 +575,8 @@ bool ClassesSortFilterProxyModel::hasChildren(const QModelIndex &parent) const
 
 
 
-ClassesWidget::ClassesWidget(MainWindow *main, QAction *action) :
-    CutterDockWidget(main, action),
+ClassesWidget::ClassesWidget(MainWindow *main) :
+    CutterDockWidget(main),
     ui(new Ui::ClassesWidget)
 {
     ui->setupUi(this);
@@ -590,7 +590,8 @@ ClassesWidget::ClassesWidget(MainWindow *main, QAction *action) :
 
     ui->classSourceCombo->setCurrentIndex(1);
 
-    connect(ui->classSourceCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(refreshClasses()));
+    connect<void(QComboBox::*)(int)>(ui->classSourceCombo, &QComboBox::currentIndexChanged,
+                                     this, &ClassesWidget::refreshClasses);
     connect(ui->classesTreeView, &QTreeView::customContextMenuRequested, this, &ClassesWidget::showContextMenu);
 
     refreshClasses();
@@ -740,14 +741,14 @@ void ClassesWidget::on_editMethodAction_triggered()
     EditMethodDialog::editMethod(className, methName, this);
 }
 
-
 void ClassesWidget::on_newClassAction_triggered()
 {
-    QString name;
-    if (!RenameDialog::showDialog(tr("Create new Class"), &name, tr("Class Name"), this) || name.isEmpty()) {
-        return;
+    bool ok;
+    QString name = QInputDialog::getText(this, tr("Create new Class"),
+                            tr("Class Name:"), QLineEdit::Normal, QString(), &ok);
+    if (ok && !name.isEmpty()) {
+        Core()->createNewClass(name);
     }
-    Core()->createNewClass(name);
 }
 
 void ClassesWidget::on_deleteClassAction_triggered()
@@ -770,9 +771,10 @@ void ClassesWidget::on_renameClassAction_triggered()
         return;
     }
     QString oldName = index.data(ClassesModel::NameRole).toString();
-    QString newName = oldName;
-    if (!RenameDialog::showDialog(tr("Rename Class %1").arg(oldName), &newName, tr("Class Name"), this) || newName.isEmpty()) {
-        return;
+    bool ok;
+    QString newName = QInputDialog::getText(this, tr("Rename Class %1").arg(oldName),
+                                         tr("Class name:"), QLineEdit::Normal, oldName, &ok);
+    if (ok && !newName.isEmpty()) {
+            Core()->renameClass(oldName, newName);
     }
-    Core()->renameClass(oldName, newName);
 }
