@@ -1,26 +1,22 @@
 #include "CutterDockWidget.h"
 #include "core/MainWindow.h"
 
-#include <QAction>
 #include <QEvent>
 #include <QtWidgets/QShortcut>
 
-CutterDockWidget::CutterDockWidget(MainWindow *parent, QAction *action) :
-    QDockWidget(parent),
-    mainWindow(parent),
-    action(action)
+CutterDockWidget::CutterDockWidget(MainWindow *parent, QAction *)
+    : CutterDockWidget(parent)
 {
-    if (action) {
-        addAction(action);
-        connect(action, &QAction::triggered, this, &CutterDockWidget::toggleDockWidget);
-    }
-    if (parent) {
-        parent->addWidget(this);
-    }
+}
 
+CutterDockWidget::CutterDockWidget(MainWindow *parent) :
+    QDockWidget(parent),
+    mainWindow(parent)
+{
     // Install event filter to catch redraw widgets when needed
     installEventFilter(this);
     updateIsVisibleToUser();
+    connect(toggleViewAction(), &QAction::triggered, this, &QWidget::raise);
 }
 
 CutterDockWidget::~CutterDockWidget() = default;
@@ -38,6 +34,28 @@ bool CutterDockWidget::eventFilter(QObject *object, QEvent *event)
     return QDockWidget::eventFilter(object, event);
 }
 
+QVariantMap CutterDockWidget::serializeViewProprties()
+{
+    return {};
+}
+
+void CutterDockWidget::deserializeViewProperties(const QVariantMap &)
+{
+}
+
+void CutterDockWidget::ignoreVisibilityStatus(bool ignore)
+{
+    this->ignoreVisibility = ignore;
+    updateIsVisibleToUser();
+}
+
+void CutterDockWidget::raiseMemoryWidget()
+{
+    show();
+    raise();
+    widgetToFocusOnRaise()->setFocus(Qt::FocusReason::TabFocusReason);
+}
+
 void CutterDockWidget::toggleDockWidget(bool show)
 {
     if (!show) {
@@ -56,7 +74,7 @@ QWidget *CutterDockWidget::widgetToFocusOnRaise()
 void CutterDockWidget::updateIsVisibleToUser()
 {
     // Check if the user can actually see the widget.
-    bool visibleToUser = isVisible() && !visibleRegion().isEmpty();
+    bool visibleToUser = isVisible() && !visibleRegion().isEmpty() && !ignoreVisibility;
     if (visibleToUser == isVisibleToUserCurrent) {
         return;
     }
@@ -68,25 +86,21 @@ void CutterDockWidget::updateIsVisibleToUser()
 
 void CutterDockWidget::closeEvent(QCloseEvent *event)
 {
-    if (action) {
-        this->action->setChecked(false);
-    }
     QDockWidget::closeEvent(event);
     if (isTransient) {
         if (mainWindow) {
             mainWindow->removeWidget(this);
         }
+
+        // remove parent, otherwise dock layout may still decide to use this widget which is about to be deleted
+        setParent(nullptr);
+
         deleteLater();
     }
 
     emit closed();
 }
 
-QAction *CutterDockWidget::getBoundAction() const
-{
-    return action;
-}
-
 QString CutterDockWidget::getDockNumber()
 {
     auto name = this->objectName();
