@@ -1,5 +1,5 @@
 #include "CutterTreeWidget.h"
-#include "MainWindow.h"
+#include "core/MainWindow.h"
 
 CutterTreeWidget::CutterTreeWidget(QObject *parent) :
     QObject(parent),
@@ -23,4 +23,9 @@ void CutterTreeWidget::showItemsNumber(int count)
     }
 }
 
+void CutterTreeWidget::showStatusBar(bool show)
+{
+    bar->setVisible(show);
+}
+
 CutterTreeWidget::~CutterTreeWidget() {}
