@@ -5,12 +5,10 @@
 #include "core/MainWindow.h"
 #include "common/Colors.h"
 #include "common/Configuration.h"
-#include "common/CachedFontMetrics.h"
 #include "common/TempConfig.h"
 #include "common/SyntaxHighlighter.h"
 #include "common/BasicBlockHighlighter.h"
 #include "common/BasicInstructionHighlighter.h"
-#include "dialogs/MultitypeFileSaveDialog.h"
 #include "common/Helpers.h"
 
 #include <QColorDialog>
@@ -23,29 +21,20 @@
 #include <QToolTip>
 #include <QTextDocument>
 #include <QTextEdit>
-#include <QFileDialog>
-#include <QFile>
 #include <QVBoxLayout>
 #include <QRegularExpression>
-#include <QStandardPaths>
 #include <QClipboard>
 #include <QApplication>
 #include <QAction>
 
 #include <cmath>
 
-const int DisassemblerGraphView::KEY_ZOOM_IN = Qt::Key_Plus + Qt::ControlModifier;
-const int DisassemblerGraphView::KEY_ZOOM_OUT = Qt::Key_Minus + Qt::ControlModifier;
-const int DisassemblerGraphView::KEY_ZOOM_RESET = Qt::Key_Equal + Qt::ControlModifier;
-
 DisassemblerGraphView::DisassemblerGraphView(QWidget *parent, CutterSeekable *seekable,
                                              MainWindow *mainWindow, QList<QAction *> additionalMenuActions)
-    : GraphView(parent),
-      mFontMetrics(nullptr),
+    : CutterGraphView(parent),
       blockMenu(new DisassemblyContextMenu(this, mainWindow)),
       contextMenu(new QMenu(this)),
       seekable(seekable),
-      actionExportGraph(this),
       actionUnhighlight(this),
       actionUnhighlightInstruction(this)
 {
@@ -53,78 +42,45 @@ DisassemblerGraphView::DisassemblerGraphView(QWidget *parent, CutterSeekable *se
     auto *layout = new QVBoxLayout(this);
     // Signals that require a refresh all
     connect(Core(), SIGNAL(refreshAll()), this, SLOT(refreshView()));
-    connect(Core(), SIGNAL(commentsChanged()), this, SLOT(refreshView()));
-    connect(Core(), SIGNAL(functionRenamed(const QString &, const QString &)), this,
-            SLOT(refreshView()));
+    connect(Core(), &CutterCore::commentsChanged, this, &DisassemblerGraphView::refreshView);
+    connect(Core(), &CutterCore::functionRenamed, this, &DisassemblerGraphView::refreshView);
     connect(Core(), SIGNAL(flagsChanged()), this, SLOT(refreshView()));
     connect(Core(), SIGNAL(varsChanged()), this, SLOT(refreshView()));
     connect(Core(), SIGNAL(instructionChanged(RVA)), this, SLOT(refreshView()));
+    connect(Core(), &CutterCore::breakpointsChanged, this, &DisassemblerGraphView::refreshView);
     connect(Core(), SIGNAL(functionsChanged()), this, SLOT(refreshView()));
-    connect(Core(), SIGNAL(graphOptionsChanged()), this, SLOT(refreshView()));
     connect(Core(), SIGNAL(asmOptionsChanged()), this, SLOT(refreshView()));
     connect(Core(), SIGNAL(refreshCodeViews()), this, SLOT(refreshView()));
 
-    connect(Config(), SIGNAL(colorsUpdated()), this, SLOT(colorsUpdatedSlot()));
-    connect(Config(), SIGNAL(fontsUpdated()), this, SLOT(fontsUpdatedSlot()));
     connectSeekChanged(false);
 
     // ESC for previous
     QShortcut *shortcut_escape = new QShortcut(QKeySequence(Qt::Key_Escape), this);
     shortcut_escape->setContext(Qt::WidgetShortcut);
-    connect(shortcut_escape, SIGNAL(activated()), seekable, SLOT(seekPrev()));
+    connect(shortcut_escape, &QShortcut::activated, seekable, &CutterSeekable::seekPrev);
 
     // Branch shortcuts
     QShortcut *shortcut_take_true = new QShortcut(QKeySequence(Qt::Key_T), this);
     shortcut_take_true->setContext(Qt::WidgetShortcut);
-    connect(shortcut_take_true, SIGNAL(activated()), this, SLOT(takeTrue()));
+    connect(shortcut_take_true, &QShortcut::activated, this, &DisassemblerGraphView::takeTrue);
     QShortcut *shortcut_take_false = new QShortcut(QKeySequence(Qt::Key_F), this);
     shortcut_take_false->setContext(Qt::WidgetShortcut);
-    connect(shortcut_take_false, SIGNAL(activated()), this, SLOT(takeFalse()));
+    connect(shortcut_take_false, &QShortcut::activated, this, &DisassemblerGraphView::takeFalse);
 
     // Navigation shortcuts
     QShortcut *shortcut_next_instr = new QShortcut(QKeySequence(Qt::Key_J), this);
     shortcut_next_instr->setContext(Qt::WidgetShortcut);
-    connect(shortcut_next_instr, SIGNAL(activated()), this, SLOT(nextInstr()));
+    connect(shortcut_next_instr, &QShortcut::activated, this, &DisassemblerGraphView::nextInstr);
     QShortcut *shortcut_prev_instr = new QShortcut(QKeySequence(Qt::Key_K), this);
     shortcut_prev_instr->setContext(Qt::WidgetShortcut);
-    connect(shortcut_prev_instr, SIGNAL(activated()), this, SLOT(prevInstr()));
+    connect(shortcut_prev_instr, &QShortcut::activated, this, &DisassemblerGraphView::prevInstr);
     shortcuts.append(shortcut_escape);
     shortcuts.append(shortcut_next_instr);
     shortcuts.append(shortcut_prev_instr);
 
-    // Export Graph menu
-    actionExportGraph.setText(tr("Export Graph"));
-    connect(&actionExportGraph, SIGNAL(triggered(bool)), this, SLOT(on_actionExportGraph_triggered()));
-
     // Context menu that applies to everything
     contextMenu->addAction(&actionExportGraph);
-    static const std::pair<QString, GraphView::Layout> LAYOUT_CONFIG[] = {
-        {tr("Grid narrow"), GraphView::Layout::GridNarrow}
-        , {tr("Grid medium"), GraphView::Layout::GridMedium}
-        , {tr("Grid wide"), GraphView::Layout::GridWide}
-#ifdef CUTTER_ENABLE_GRAPHVIZ
-        , {tr("Graphviz polyline"), GraphView::Layout::GraphvizPolyline}
-        , {tr("Graphviz polyline LR"), GraphView::Layout::GraphvizPolylineLR}
-        , {tr("Graphviz ortho"), GraphView::Layout::GraphvizOrtho}
-        , {tr("Graphviz ortho LR"), GraphView::Layout::GraphvizOrthoLR}
-#endif
-    };
-    auto layoutMenu = contextMenu->addMenu(tr("Layout"));
-    QActionGroup *layoutGroup = new QActionGroup(layoutMenu);
-    for (auto &item : LAYOUT_CONFIG) {
-        auto action = layoutGroup->addAction(item.first);
-        action->setCheckable(true);
-        GraphView::Layout layout = item.second;
-        connect(action, &QAction::triggered, this, [this, layout]() {
-            setGraphLayout(layout);
-            refreshView();
-            onSeekChanged(this->seekable->getOffset()); // try to keep the view on current block
-        });
-        if (layout == getGraphLayout()) {
-            action->setChecked(true);
-        }
-    }
-    layoutMenu->addActions(layoutGroup->actions());
+    contextMenu->addMenu(layoutMenu);
     contextMenu->addSeparator();
     contextMenu->addActions(additionalMenuActions);
 
@@ -178,10 +134,6 @@ DisassemblerGraphView::DisassemblerGraphView(QWidget *parent, CutterSeekable *se
     blockMenu->addSeparator();
     blockMenu->addActions(contextMenu->actions());
 
-
-    initFont();
-    colorsUpdatedSlot();
-
     connect(blockMenu, &DisassemblyContextMenu::copy, this, &DisassemblerGraphView::copySelection);
 
     // Add header as widget to layout so it stretches to the layout width
@@ -211,9 +163,8 @@ DisassemblerGraphView::~DisassemblerGraphView()
 
 void DisassemblerGraphView::refreshView()
 {
-    initFont();
+    CutterGraphView::refreshView();
     loadCurrentGraph();
-    viewport()->update();
     emit viewRefreshed();
 }
 
@@ -349,10 +300,10 @@ void DisassemblerGraphView::loadCurrentGraph()
 
         addBlock(gb);
     }
-    cleanupEdges();
+    cleanupEdges(blocks);
 
     if (!func["blocks"].toArray().isEmpty()) {
-        computeGraph(entry);
+        computeGraphPlacement();
     }
 }
 
@@ -395,36 +346,6 @@ void DisassemblerGraphView::prepareGraphNode(GraphBlock &block)
     block.height = (height * charHeight) + extra;
 }
 
-void DisassemblerGraphView::cleanupEdges()
-{
-    for (auto &blockIt : blocks) {
-        auto &block = blockIt.second;
-        auto outIt = block.edges.begin();
-        std::unordered_set<ut64> seenEdges;
-        for (auto it = block.edges.begin(), end = block.edges.end(); it != end; ++it) {
-            // remove edges going  to different functions
-            // and remove duplicate edges, common in switch statements
-            if (blocks.find(it->target) != blocks.end() &&
-                    seenEdges.find(it->target) == seenEdges.end()) {
-                *outIt++ = *it;
-                seenEdges.insert(it->target);
-            }
-        }
-        block.edges.erase(outIt, block.edges.end());
-    }
-}
-
-void DisassemblerGraphView::initFont()
-{
-    setFont(Config()->getFont());
-    QFontMetricsF metrics(font());
-    baseline = int(metrics.ascent());
-    charWidth = metrics.width('X');
-    charHeight = static_cast<int>(metrics.height());
-    charOffset = 0;
-    mFontMetrics.reset(new CachedFontMetrics<qreal>(font()));
-}
-
 void DisassemblerGraphView::drawBlock(QPainter &p, GraphView::GraphBlock &block, bool interactive)
 {
     QRectF blockRect(block.x, block.y, block.width, block.height);
@@ -492,7 +413,7 @@ void DisassemblerGraphView::drawBlock(QPainter &p, GraphView::GraphBlock &block,
     }
 
     // Highlight selected tokens
-    if (highlight_token != nullptr) {
+    if (interactive && highlight_token != nullptr) {
         int y = firstInstructionY;
         qreal tokenWidth = mFontMetrics->width(highlight_token->content);
 
@@ -700,33 +621,6 @@ void DisassemblerGraphView::showInstruction(GraphView::GraphBlock &block, RVA ad
     showRectangle(QRect(rect.x(), rect.y(), rect.width(), rect.height()), true);
 }
 
-// Public Slots
-
-void DisassemblerGraphView::colorsUpdatedSlot()
-{
-    disassemblyBackgroundColor = ConfigColor("gui.alt_background");
-    disassemblySelectedBackgroundColor = ConfigColor("gui.disass_selected");
-    mDisabledBreakpointColor = disassemblyBackgroundColor;
-    graphNodeColor = ConfigColor("gui.border");
-    backgroundColor = ConfigColor("gui.background");
-    disassemblySelectionColor = ConfigColor("lineHighlight");
-    PCSelectionColor = ConfigColor("highlightPC");
-
-    jmpColor = ConfigColor("graph.trufae");
-    brtrueColor = ConfigColor("graph.true");
-    brfalseColor = ConfigColor("graph.false");
-
-    mCommentColor = ConfigColor("comment");
-    initFont();
-    refreshView();
-}
-
-void DisassemblerGraphView::fontsUpdatedSlot()
-{
-    initFont();
-    refreshView();
-}
-
 DisassemblerGraphView::DisassemblyBlock *DisassemblerGraphView::blockForAddress(RVA addr)
 {
     for (auto &blockIt : disassembly_blocks) {
@@ -773,51 +667,11 @@ void DisassemblerGraphView::onSeekChanged(RVA addr)
     if (db) {
         // This is a local address! We animated to it.
         transition_dont_seek = true;
-        showBlock(&blocks[db->entry], !switchFunction);
+        showBlock(blocks[db->entry], !switchFunction);
         showInstruction(blocks[db->entry], addr);
     }
 }
 
-void DisassemblerGraphView::zoom(QPointF mouseRelativePos, double velocity)
-{
-    qreal newScale = getViewScale() * std::pow(1.25, velocity);
-    setZoom(mouseRelativePos, newScale);
-}
-
-void DisassemblerGraphView::setZoom(QPointF mouseRelativePos, double scale)
-{
-    mouseRelativePos.rx() *= size().width();
-    mouseRelativePos.ry() *= size().height();
-    mouseRelativePos /= getViewScale();
-
-    auto globalMouse = mouseRelativePos + getViewOffset();
-    mouseRelativePos *= getViewScale();
-    qreal newScale = scale;
-    newScale = std::max(newScale, 0.05);
-    mouseRelativePos /= newScale;
-    setViewScale(newScale);
-
-    // Adjusting offset, so that zooming will be approaching to the cursor.
-    setViewOffset(globalMouse.toPoint() - mouseRelativePos.toPoint());
-
-    viewport()->update();
-    emit viewZoomed();
-}
-
-void DisassemblerGraphView::zoomIn()
-{
-    zoom(QPointF(0.5, 0.5), 1);
-}
-
-void DisassemblerGraphView::zoomOut()
-{
-    zoom(QPointF(0.5, 0.5), -1);
-}
-
-void DisassemblerGraphView::zoomReset()
-{
-    setZoom(QPointF(0.5, 0.5), 1);
-}
 
 void DisassemblerGraphView::takeTrue()
 {
@@ -938,12 +792,6 @@ DisassemblerGraphView::Token *DisassemblerGraphView::getToken(Instr *instr, int
     return nullptr;
 }
 
-QPoint DisassemblerGraphView::getTextOffset(int line) const
-{
-    int padding = static_cast<int>(2 * charWidth);
-    return QPoint(padding, padding + line * charHeight);
-}
-
 QPoint DisassemblerGraphView::getInstructionOffset(const DisassemblyBlock &block, int line) const
 {
     return getTextOffset(line + static_cast<int>(block.header_text.lines.size()));
@@ -973,7 +821,7 @@ void DisassemblerGraphView::blockClicked(GraphView::GraphBlock &block, QMouseEve
 }
 
 void DisassemblerGraphView::blockContextMenuRequested(GraphView::GraphBlock &block,
-                                                      QContextMenuEvent *event, QPoint pos)
+                                                      QContextMenuEvent *event, QPoint /*pos*/)
 {
     const RVA offset = this->seekable->getOffset();
     actionUnhighlight.setVisible(Core()->getBBHighlighter()->getBasicBlock(block.entry));
@@ -992,6 +840,21 @@ void DisassemblerGraphView::contextMenuEvent(QContextMenuEvent *event)
     }
 }
 
+void DisassemblerGraphView::showExportDialog()
+{
+    QString defaultName = "graph";
+    if (auto f = Core()->functionIn(currentFcnAddr)) {
+        QString functionName = f->name;
+        // don't confuse image type guessing and make c++ names somewhat usable
+        functionName.replace(QRegularExpression("[.:]"), "_");
+        functionName.remove(QRegularExpression("[^a-zA-Z0-9_].*"));
+        if (!functionName.isEmpty()) {
+            defaultName = functionName;
+        }
+    }
+    showExportGraphDialog(defaultName, "agf", currentFcnAddr);
+}
+
 void DisassemblerGraphView::blockDoubleClicked(GraphView::GraphBlock &block, QMouseEvent *event,
                                                QPoint pos)
 {
@@ -1032,91 +895,6 @@ void DisassemblerGraphView::blockTransitionedTo(GraphView::GraphBlock *to)
     seekLocal(to->entry);
 }
 
-bool DisassemblerGraphView::event(QEvent *event)
-{
-    switch (event->type()) {
-    case QEvent::ShortcutOverride: {
-        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
-        int key = keyEvent->key() + keyEvent->modifiers();
-        if (key == KEY_ZOOM_OUT || key == KEY_ZOOM_RESET
-                || key == KEY_ZOOM_IN || (key == (KEY_ZOOM_IN | Qt::ShiftModifier))) {
-            event->accept();
-            return true;
-        }
-        break;
-    }
-    case QEvent::KeyPress: {
-        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
-        int key = keyEvent->key() + keyEvent->modifiers();
-        if (key == KEY_ZOOM_IN || (key == (KEY_ZOOM_IN | Qt::ShiftModifier))) {
-            zoomIn();
-            return true;
-        } else if (key == KEY_ZOOM_OUT) {
-            zoomOut();
-            return true;
-        } else if (key == KEY_ZOOM_RESET) {
-            zoomReset();
-            return true;
-        }
-        break;
-    }
-    default:
-        break;
-    }
-    return GraphView::event(event);
-}
-
-
-Q_DECLARE_METATYPE(DisassemblerGraphView::GraphExportType);
-
-void DisassemblerGraphView::on_actionExportGraph_triggered()
-{
-    QVector<MultitypeFileSaveDialog::TypeDescription> types = {
-        {tr("PNG (*.png)"), "png", QVariant::fromValue(GraphExportType::Png)},
-        {tr("JPEG (*.jpg)"), "jpg", QVariant::fromValue(GraphExportType::Jpeg)},
-        {tr("SVG (*.svg)"), "svg", QVariant::fromValue(GraphExportType::Svg)}
-    };
-    bool hasGraphviz = !QStandardPaths::findExecutable("dot").isEmpty()
-                       || !QStandardPaths::findExecutable("xdot").isEmpty();
-    if (hasGraphviz) {
-        types.append({
-            {tr("Graphviz dot (*.dot)"), "dot", QVariant::fromValue(GraphExportType::GVDot)},
-            {tr("Graphviz json (*.json)"), "json", QVariant::fromValue(GraphExportType::GVJson)},
-            {tr("Graphviz gif (*.gif)"), "gif", QVariant::fromValue(GraphExportType::GVGif)},
-            {tr("Graphviz png (*.png)"), "png", QVariant::fromValue(GraphExportType::GVPng)},
-            {tr("Graphviz jpg (*.jpg)"), "jpg", QVariant::fromValue(GraphExportType::GVJpeg)},
-            {tr("Graphviz PostScript (*.ps)"), "ps", QVariant::fromValue(GraphExportType::GVPostScript)},
-            {tr("Graphviz svg (*.svg)"), "svg", QVariant::fromValue(GraphExportType::GVSvg)}
-        });
-    }
-
-    QString defaultName = "graph";
-    if (auto f = Core()->functionIn(currentFcnAddr)) {
-        QString functionName = f->name;
-        // don't confuse image type guessing and make c++ names somewhat usable
-        functionName.replace(QRegularExpression("[.:]"), "_");
-        functionName.remove(QRegularExpression("[^a-zA-Z0-9_].*"));
-        if (!functionName.isEmpty()) {
-            defaultName = functionName;
-        }
-    }
-
-
-    MultitypeFileSaveDialog dialog(this, tr("Export Graph"));
-    dialog.setTypes(types);
-    dialog.selectFile(defaultName);
-    if (!dialog.exec())
-        return;
-
-    auto selectedType = dialog.selectedType();
-    if (!selectedType.data.canConvert<GraphExportType>()) {
-        qWarning() << "Bad selected type, should not happen.";
-        return;
-    }
-    QString filePath = dialog.selectedFiles().first();
-    exportGraph(filePath, selectedType.data.value<GraphExportType>());
-
-}
 
 void DisassemblerGraphView::onActionHighlightBITriggered()
 {
@@ -1155,100 +933,11 @@ void DisassemblerGraphView::onActionUnhighlightBITriggered()
     Config()->colorsUpdated();
 }
 
-void DisassemblerGraphView::exportGraph(QString filePath, GraphExportType type)
+void DisassemblerGraphView::restoreCurrentBlock()
 {
-    bool graphTransparent = Config()->getBitmapTransparentState();
-    double graphScaleFactor = Config()->getBitmapExportScaleFactor();
-    switch (type) {
-    case GraphExportType::Png:
-        this->saveAsBitmap(filePath, "png", graphScaleFactor, graphTransparent);
-        break;
-    case GraphExportType::Jpeg:
-        this->saveAsBitmap(filePath, "jpg", graphScaleFactor, false);
-        break;
-    case GraphExportType::Svg:
-        this->saveAsSvg(filePath);
-        break;
-
-    case GraphExportType::GVDot: {
-        QFile file(filePath);
-        if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
-            qWarning() << "Can't open file";
-            return;
-        }
-        QTextStream fileOut(&file);
-        fileOut << Core()->cmd(QString("agfd 0x%1").arg(currentFcnAddr, 0, 16));
-    }
-    break;
-
-    case GraphExportType::GVJson:
-        exportR2GraphvizGraph(filePath, "json");
-        break;
-    case GraphExportType::GVGif:
-        exportR2GraphvizGraph(filePath, "gif");
-        break;
-    case GraphExportType::GVPng:
-        exportR2GraphvizGraph(filePath, "png");
-        break;
-    case GraphExportType::GVJpeg:
-        exportR2GraphvizGraph(filePath, "jpg");
-        break;
-    case GraphExportType::GVPostScript:
-        exportR2GraphvizGraph(filePath, "ps");
-        break;
-    case GraphExportType::GVSvg:
-        exportR2GraphvizGraph(filePath, "svg");
-        break;
-    }
+    onSeekChanged(this->seekable->getOffset()); // try to keep the view on current block
 }
 
-void DisassemblerGraphView::exportR2GraphvizGraph(QString filePath, QString type)
-{
-    TempConfig tempConfig;
-    tempConfig.set("graph.gv.format", type);
-    qWarning() << Core()->cmdRaw(QString("agfw \"%1\" @ 0x%2")
-                                 .arg(filePath).arg(currentFcnAddr, 0, 16));
-}
-
-void DisassemblerGraphView::mousePressEvent(QMouseEvent *event)
-{
-    GraphView::mousePressEvent(event);
-    emit graphMoved();
-}
-
-void DisassemblerGraphView::mouseMoveEvent(QMouseEvent *event)
-{
-    GraphView::mouseMoveEvent(event);
-    emit graphMoved();
-}
-
-void DisassemblerGraphView::wheelEvent(QWheelEvent *event)
-{
-    // when CTRL is pressed, we zoom in/out with mouse wheel
-    if (Qt::ControlModifier == event->modifiers()) {
-        const QPoint numDegrees = event->angleDelta() / 8;
-        if (!numDegrees.isNull()) {
-            int numSteps = numDegrees.y() / 15;
-
-            QPointF relativeMousePos = event->pos();
-            relativeMousePos.rx() /= size().width();
-            relativeMousePos.ry() /= size().height();
-
-            zoom(relativeMousePos, numSteps);
-        }
-        event->accept();
-    } else {
-        // use mouse wheel for scrolling when CTRL is not pressed
-        GraphView::wheelEvent(event);
-    }
-    emit graphMoved();
-}
-
-void DisassemblerGraphView::resizeEvent(QResizeEvent *event)
-{
-    GraphView::resizeEvent(event);
-    emit resized();
-}
 
 void DisassemblerGraphView::paintEvent(QPaintEvent *event)
 {
