@@ -61,7 +61,7 @@ class ZignaturesWidget : public CutterDockWidget
     Q_OBJECT
 
 public:
-    explicit ZignaturesWidget(MainWindow *main, QAction *action = nullptr);
+    explicit ZignaturesWidget(MainWindow *main);
     ~ZignaturesWidget();
 
 private slots:
